// API 基础配置
export const API_CONFIG = {
  // 基础URL
  BASE_URL: import.meta.env.VITE_BASE_URL || 'https://script.jiaweijia.cn/script',
  
  // 超时时间
  TIMEOUT: 15000,
  
  // 重试次数
  RETRY_COUNT: 3,
  
  // 重试延迟（毫秒）
  RETRY_DELAY: 1000,
  
  // 默认请求头
  DEFAULT_HEADERS: {
    'Content-Type': 'application/json',
    'Accept': 'application/json',
  },
  
  // 文件上传请求头
  UPLOAD_HEADERS: {
    'Content-Type': 'multipart/form-data',
  },
  
  // 响应状态码
  STATUS_CODES: {
    SUCCESS: 200,
    UNAUTHORIZED: 401,
    FORBIDDEN: 403,
    NOT_FOUND: 404,
    SERVER_ERROR: 500,
  },
  
  // 业务状态码
  BUSINESS_CODES: {
    SUCCESS: 0,
    FAIL: -1,
    TOKEN_EXPIRED: 401,
    PERMISSION_DENIED: 403,
  }
}

// 环境配置
export const ENV_CONFIG = {
  isDev: import.meta.env.DEV,
  isProd: import.meta.env.PROD,
  mode: import.meta.env.MODE,
}

// API 端点配置
export const API_ENDPOINTS = {
  // 编辑器相关
  EDITOR: {
    CREATE_ORDER: '/cpq/3d/create/order',
    SAVE_PROJECT: '/editor/project/save',
    LOAD_PROJECT: '/editor/project/load',
    DELETE_PROJECT: '/editor/project/delete',
  },
  
  // 文件相关
  FILE: {
    UPLOAD: '/file/upload',
    DOWNLOAD: '/file/download',
    DELETE: '/file/delete',
    LIST: '/file/list',
  },
  
  // 用户相关
  USER: {
    LOGIN: '/user/login',
    LOGOUT: '/user/logout',
    INFO: '/user/info',
    UPDATE: '/user/update',
  },
  
  // 资源相关
  RESOURCE: {
    LIST: '/resource/list',
    UPLOAD: '/resource/upload',
    DELETE: '/resource/delete',
  }
} 