// 通用响应类型
export interface ApiResponse<T = any> {
  code: number
  message: string
  data: T
  success: boolean
}

// 请求配置类型
export interface RequestConfig {
  url: string
  method?: 'GET' | 'POST' | 'PUT' | 'DELETE' | 'PATCH' | 'HEAD'
  params?: Record<string, any>
  data?: any
  headers?: Record<string, string>
  timeout?: number
  responseType?: 'json' | 'blob' | 'text' | 'arraybuffer'
}

// 文件上传配置
export interface UploadConfig {
  file: File | Blob
  filename?: string
  fieldName?: string
  data?: Record<string, any>
  onProgress?: (progress: number) => void
}

// 文件下载配置
export interface DownloadConfig {
  url: string
  filename?: string
  params?: Record<string, any>
  onProgress?: (progress: number) => void
}

// 分页请求参数
export interface PaginationParams {
  page: number
  pageSize: number
  [key: string]: any
}

// 分页响应数据
export interface PaginationResponse<T> {
  list: T[]
  total: number
  page: number
  pageSize: number
  totalPages: number
}

// 错误类型
export interface ApiError {
  code: number
  message: string
  details?: any
} 