/**
 * 环境变量配置
 */

// 获取环境变量
export const getEnv = (): string => {
  return import.meta.env.MODE
}

// 获取环境变量前缀
export const getEnvConfig = (): Partial<ViteEnv> => {
  const envConfig = import.meta.env as Record<string, any>
  const ret: any = {}

  for (const envName of Object.keys(envConfig)) {
    if (envName.startsWith('VITE_')) {
      let realName = envConfig[envName]
      if (typeof realName === 'string') {
        realName = realName.replace(/\\n/g, '\n')
        realName = realName === 'true' ? true : realName === 'false' ? false : realName
      }
      ret[envName] = realName
    }
  }
  return ret
}

// 环境变量类型定义
export interface ViteEnv {
  VITE_APP_TITLE: string
  VITE_APP_PORT: number
  VITE_APP_BASE_API: string
  VITE_APP_ENV: string
  VITE_APP_BASE_URL: string
}

// 默认环境配置
export const defaultEnvConfig: ViteEnv = {
  VITE_APP_TITLE: 'Vite应用',
  VITE_APP_PORT: 8080,
  VITE_APP_BASE_API: '/api',
  VITE_APP_ENV: 'development',
  VITE_APP_BASE_URL: '/'
}

// 获取当前环境配置
export const envConfig = {
  ...defaultEnvConfig,
  ...getEnvConfig()
} 