/**
 * Pinia状态管理
 */
import { createPinia } from 'pinia'
import { storage } from '../utils/storage'

// 创建pinia实例
const pinia = createPinia()

// 添加持久化插件
pinia.use(({ store }) => {
  // 从存储中恢复状态
  const storageKey = `store_${store.$id}`
  const savedState = storage.local.get(storageKey)
  
  if (savedState) {
    store.$patch(savedState)
  }

  // 监听状态变化并持久化
  store.$subscribe((_, state) => {
    storage.local.set(storageKey, state)
  })
})

export default pinia

// 导出所有store
export * from './modules/user'
export * from './modules/app' 